import { IDictionary } from "../lib/util";
export interface ICapabilitiesList {
    apm?: {
        applePay?: boolean;
        googlePay?: boolean;
        clickToPay?: boolean;
    };
    binCheck?: {
        hsaFsa?: boolean;
        surcharge?: boolean;
    };
    consumerAuthentication?: boolean;
    env?: string;
    tokenization?: {
        cardNotPresent?: boolean;
        cardPresent?: boolean;
        eCheck?: boolean;
        gift?: boolean;
    };
}
export interface ISuccess {
    details: {
        accountId?: string;
        accountName?: string;
        accountNumber?: string;
        accountLast4?: string;
        billingAddress?: PaymentAddress;
        canSurcharge?: boolean;
        cardBin?: string;
        cardLast4?: string;
        cardNumber?: string;
        cardSecurityCode?: boolean;
        cardType?: string;
        cardholderName?: string;
        expiryMonth?: string;
        expiryYear?: string;
        fingerprint?: string;
        fingerprintPresenceIndicator?: string;
        isHsaFsa?: boolean;
        merchantId?: string;
        merchantName?: string;
        orderId?: string;
        reference?: string;
        apmProvider?: string;
        installment?: {
            id: string;
            reference: string;
        };
        currencyConversion?: {
            id: string;
        };
    };
    methodName?: string;
    payerEmail?: string;
    payerName?: string;
    payerPhone?: string;
    paymentReference: string;
    requestId?: string;
    shippingAddress?: PaymentAddress;
    shippingOptions?: PaymentShippingOption[];
}
export interface IError {
    error: boolean;
    reasons?: IErrorReason[];
}
export interface IErrorReason {
    code: string;
    message: string;
}
export interface IActions {
    normalizeResponse: (data: IDictionary) => ISuccess | IError;
    setup?: () => any;
    tokenize: (url: string, env: string, data: IDictionary) => Promise<any>;
    validateData: (data: IDictionary) => IErrorReason[];
    queryInstallmentPlans?: (url: string, env: string, data: IDictionary) => Promise<any>;
    queryCurrencyConversion?: (url: string, env: string, data: IDictionary) => Promise<any>;
    getQRCodePaymentMethods?: (url: string, env: string, data: IDictionary) => Promise<any>;
}
export interface IUrlGenerators {
    assetBaseUrl?: (result: string) => string;
    tokenization: (prod: boolean) => string;
    queryInstallmentPlans?: (prod: boolean) => string;
    queryCurrencyConversionUrl?: () => string;
    getQRCodePaymentMethodsUrl?: () => string;
}
export interface IGatewayModule {
    [key: string]: any;
    actions: IActions;
    getEnv: (options: object) => string;
    requiredSettings: string[];
    supports: ICapabilitiesList;
    urls: IUrlGenerators;
}
export interface IGatewayList {
    [key: string]: IGatewayModule;
}
export declare const availableGateways: IGatewayList;
